Package 'malariaEquilibriumVivax'

Title: Return equilibrium solution to malaria transmission model (P. vivax)
Description: Often we are interested in the state of a given malaria transmission model at equilibrium. However, some models (e.g. the Griffin et al. 2014 model, the White et al. 2018 model) are quite complex, and can result in equilibrium solutions that are fairly in-depth. In these situations it is useful to have a "canonical" equilibrium solution that is tried and tested, and can be used reliably by multiple users. This package complement the malariaEquilibriumVivax package to store canonical equilibrium solutions for Plasmodium vivax malaria models.
Authors: Richard Sheppard [aut, cre], Pete Winskill [aut], Giovanni Charles [aut]
Maintainer: Richard Sheppard <[email protected]>
License: MIT + file LICENSE
Version: 1.0.1
Built: 2026-06-02 07:13:20 UTC
Source: https://github.com/mrc-ide/malariaEquilibriumVivax

Help Index


malariaEquilibriumVivax

Description

Often we are interested in the state of a given malaria transmission model at equilibrium. However, some models (e.g. the Griffin et al. 2014 model, the White et al. 2018 model) are quite complex, and can result in equilibrium solutions that are fairly in-depth. In these situations it is useful to have a "canonical" equilibrium solution that is tried and tested, and can be used reliably by multiple users. This package complement the malariaEquilibriumVivax package to store canonical equilibrium solutions for Plasmodium vivax malaria models.

Author(s)

Maintainer: Richard Sheppard [email protected]

Authors:

See Also

Useful links:


Load system file for this package

Description

Load and return file from within the inst folder of this package.

Usage

malariaEqVivax_file(name)

Arguments

name

name of file


Vivax equilibrium solution with biting heterogeneity

Description

Returns the vivax equilibrium states for the model of White et al., (2018).

Usage

vivax_equilibrium(
  EIR,
  ft,
  p,
  age = c(0, 0.2, 0.4, 0.6, 0.8, 1, 1.2, 1.4, 1.6, 1.8, 2, 2.2, 2.4, 2.6, 2.8, 3, 3.4,
    3.8, 4.2, 4.6, 5, 5.5, 6, 6.5, 7, 7.5, 8, 8.5, 9, 9.5, 10, 11, 12, 13, 14, 15, 16,
    17, 18, 19, 20, 22, 24, 26, 28, 30, 32, 34, 36, 38, 40, 45, 50, 55, 60, 65, 70, 75,
    80)
)

Arguments

EIR

EIR for adults, in units of infectious bites per person per year

ft

proportion of clinical cases effectively treated

p

vector of model parameters

age

vector of age groups, in units of years